@@ -1,6 +1,6 @@
 /* acontainer.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2004-2008,2012 Ralf Hoffmann.
+ * Copyright (C) 2004-2019 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -967,3 +967,37 @@ bool AContainer::getNoResize( int tx, int ty ) const
     if ( ty < 0 || ty >= yelems ) ty = 0;
     return elements[tx + xelems * ty].noResize();
 }
+
+void AContainer::hide()
+{
+    for ( int pos = 0; pos < ( xelems * yelems ); pos++ ) {
+        if ( elements[pos].widelem() ) {
+            auto elem = elements[pos].widelem();
+
+            auto guielem = dynamic_cast< GUIElement * >( elem );
+
+            if ( guielem ) {
+                guielem->hide();
+            }
+        } else if ( elements[pos].cont() ) {
+            elements[pos].cont()->hide();
+        }
+    }
+}
+
+void AContainer::show()
+{
+    for ( int pos = 0; pos < ( xelems * yelems ); pos++ ) {
+        if ( elements[pos].widelem() ) {
+            auto elem = elements[pos].widelem();
+
+            auto guielem = dynamic_cast< GUIElement * >( elem );
+
+            if ( guielem ) {
+                guielem->show();
+            }
+        } else if ( elements[pos].cont() ) {
+            elements[pos].cont()->show();
+        }
+    }
+}
