@@ -1,6 +1,6 @@
 /* aguix.h
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2021 Ralf Hoffmann.
+ * Copyright (C) 2001-2022 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -436,7 +436,7 @@ private:
 #endif
     int m_user_colors, m_system_colors, m_extra_colors;
 
-  std::map< AGUIXColor, col_values_t, AGUIXColor::compare_func > m_color_values;
+  std::map< AGUIXColor, col_values_t > m_color_values;
 
   XEvent LastEvent;
   std::list<AWindow*> wins;
