@@ -1,6 +1,6 @@
 /* dndelement.h
- * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001-2004 Ralf Hoffmann.
+ * This file belongs to Worker, a file manager for UN*X/X11.
+ * Copyright (C) 2001-2017 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,7 +18,6 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
-/* $Id: dndelement.h,v 1.8 2004/10/27 20:39:41 ralf Exp $ */
 
 #ifndef DNDELEMENT_H
 #define DNDELEMENT_H
@@ -45,7 +44,6 @@ protected:
   AGUIX *aguix;
   Window win;
   int delx,dely;
-  int grabbed;
   bool created;
 };
 
