@@ -1,6 +1,6 @@
 /* fieldlistview.h
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2002-2019 Ralf Hoffmann.
+ * Copyright (C) 2002-2022 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -496,6 +496,9 @@ protected:
     bool m_show_selection_in_vbar = false;
     bool m_vbar_rebuild_required = false;
 
+    int m_header_border_leftright = 3;
+    int m_header_border_topbottom = 2;
+
     void drawSelectStateVBar();
     void freeVBarSelectBuffer();
     int checkVBarSelectBuffer( int tw, int th );
