@@ -1,6 +1,6 @@
 /* request.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2006,2009,2013 Ralf Hoffmann.
+ * Copyright (C) 2001-2014 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -73,7 +73,7 @@ int Requester::request(const char *title,const char *text,const char *buttons, c
     twin = aguix->getTransientWindow();
   }
   
-  AWindow *win = new AWindow( aguix, 10, 10, 10, 10, 0, title, AWindow::AWINDOW_DIALOG );
+  AWindow *win = new AWindow( aguix, 10, 10, 10, 10, title, AWindow::AWINDOW_DIALOG );
   win->create();
   if ( twin != NULL ) {
     win->setTransientForAWindow( twin );
@@ -106,11 +106,11 @@ int Requester::request(const char *title,const char *text,const char *buttons, c
   buts = (Button**)_allocsafe( nbuttons * sizeof( Button* ) );
 
   if ( nbuttons == 1 ) {
-    buts[0] = ac1_buttons->addWidget( new Button( aguix, 0, 0, buttonss[0], 1, 0, 0 ),
+    buts[0] = ac1_buttons->addWidget( new Button( aguix, 0, 0, buttonss[0], 0 ),
                                       1, 0, AContainer::CO_FIX );
   } else {
     for ( i = 0; i < nbuttons; i++ ) {
-      buts[i] = ac1_buttons->addWidget( new Button( aguix, 0, 0, buttonss[i], 1, 0, i ),
+      buts[i] = ac1_buttons->addWidget( new Button( aguix, 0, 0, buttonss[i], i ),
                                         i, 0, AContainer::CO_FIX );
     }
   }
@@ -253,7 +253,7 @@ int Requester::string_request( const char *title, const char *text, const char *
     twin = aguix->getTransientWindow();
   }
   
-  AWindow *win = new AWindow( aguix, 10, 10, 10, 10, 0, title, AWindow::AWINDOW_DIALOG );
+  AWindow *win = new AWindow( aguix, 10, 10, 10, 10, title, AWindow::AWINDOW_DIALOG );
   win->create();
   if ( twin != NULL ) {
     win->setTransientForAWindow( twin );
@@ -292,11 +292,11 @@ int Requester::string_request( const char *title, const char *text, const char *
   buts = (Button**)_allocsafe( nbuttons * sizeof( Button* ) );
 
   if ( nbuttons == 1 ) {
-    buts[0] = ac1_buttons->addWidget( new Button( aguix, 0, 0, buttonss[0], 1, 0, 0 ),
+    buts[0] = ac1_buttons->addWidget( new Button( aguix, 0, 0, buttonss[0], 0 ),
                                       1, 0, AContainer::CO_FIX );
   } else {
     for ( i = 0; i < nbuttons; i++ ) {
-      buts[i] = ac1_buttons->addWidget( new Button( aguix, 0, 0, buttonss[i], 1, 0, i ),
+      buts[i] = ac1_buttons->addWidget( new Button( aguix, 0, 0, buttonss[i], i ),
                                         i, 0, AContainer::CO_FIX );
     }
   }
@@ -476,7 +476,7 @@ int Requester::request_choose( const char *title,
     twin = aguix->getTransientWindow();
   }
   
-  AWindow *win = new AWindow( aguix, 10, 10, 10, 10, 0, title, AWindow::AWINDOW_DIALOG );
+  AWindow *win = new AWindow( aguix, 10, 10, 10, 10, title, AWindow::AWINDOW_DIALOG );
   win->create();
   if ( twin != NULL ) {
     win->setTransientForAWindow( twin );
@@ -495,7 +495,7 @@ int Requester::request_choose( const char *title,
   ac1_1->setMaxSpace( 5 );
 
   for ( i = 0; i < lines; i++ ) {
-    ac1_1->addWidget( new Text( aguix, 0, 0, liness[i], 1 ),
+    ac1_1->addWidget( new Text( aguix, 0, 0, liness[i] ),
 		0, i, AContainer::CO_INCWNR );
   }
   
@@ -508,7 +508,7 @@ int Requester::request_choose( const char *title,
   ac1_2->setBorderWidth( 0 );
   ChooseButton *cb1 = ac1_2->addWidget( new ChooseButton( aguix, 0,
                                                           0, choose_var,
-                                                          choose_text, LABEL_RIGHT, 1, 1 ),
+                                                          choose_text, LABEL_RIGHT, 1 ),
                                         1, 0, AContainer::CO_FIXNR );
   AContainer *ac1_3 = ac1->add( new AContainer( win, nbuttons, 1 ), 0, 2 );
   ac1_3->setMinSpace( 5 );
@@ -517,7 +517,7 @@ int Requester::request_choose( const char *title,
 
   buts = (Button**)_allocsafe( nbuttons * sizeof( Button* ) );
   for ( i = 0; i < nbuttons; i++ ) {
-    buts[i] = ac1_3->addWidget( new Button( aguix, 0, 0, buttonss[i], 1, 0, i ),
+    buts[i] = ac1_3->addWidget( new Button( aguix, 0, 0, buttonss[i], i ),
                                 i, 0, AContainer::CO_FIX );
   }
   for ( i = 0; i < nbuttons; i++ ) {
@@ -664,7 +664,7 @@ int Requester::request( const char *title, TextStorage &ts, const char *buttons,
     twin = aguix->getTransientWindow();
   }
   
-  AWindow *win = new AWindow( aguix, 10, 10, 10, 10, 0, title, AWindow::AWINDOW_DIALOG );
+  AWindow *win = new AWindow( aguix, 10, 10, 10, 10, title, AWindow::AWINDOW_DIALOG );
   win->create();
   if ( twin != NULL ) {
     win->setTransientForAWindow( twin );
@@ -676,7 +676,7 @@ int Requester::request( const char *title, TextStorage &ts, const char *buttons,
   ac1->setMinSpace( 5 );
   ac1->setMaxSpace( 5 );
 
-  TextView *tv = new TextView( aguix, 0, 0, 100, 100, 0, "", ts );
+  TextView *tv = new TextView( aguix, 0, 0, 100, 100, "", ts );
   tv->setDisplayFocus( true );
   ac1->addWidget( tv, 0, 0, AContainer::CO_MIN );
   tv->create();
@@ -698,7 +698,7 @@ int Requester::request( const char *title, TextStorage &ts, const char *buttons,
     ac1_3->setBorderWidth( 0 );
     
     buts = (Button**)_allocsafe( nbuttons * sizeof( Button* ) );
-    buts[0] = ac1_3->addWidget( new Button( aguix, 0, 0, buttonss[0], 1, 0, 0 ),
+    buts[0] = ac1_3->addWidget( new Button( aguix, 0, 0, buttonss[0], 0 ),
                                 1, 0, AContainer::CO_FIX );
   } else {
     AContainer *ac1_3 = ac1->add( new AContainer( win, nbuttons, 1 ), 0, 1 );
@@ -708,7 +708,7 @@ int Requester::request( const char *title, TextStorage &ts, const char *buttons,
     
     buts = (Button**)_allocsafe( nbuttons * sizeof( Button* ) );
     for ( i = 0; i < nbuttons; i++ ) {
-      buts[i] = ac1_3->addWidget( new Button( aguix, 0, 0, buttonss[i], 1, 0, i ),
+      buts[i] = ac1_3->addWidget( new Button( aguix, 0, 0, buttonss[i], i ),
                                   i, 0, AContainer::CO_FIX );
     }
   }
@@ -824,3 +824,257 @@ int Requester::request( const char *title, TextStorage &ts, const char *buttons,
   _freesafe( buts );
   return endmode;
 }
+
+int Requester::string_request_choose( const char *title,
+                                      const char *text,
+                                      const char *default_str,
+                                      const char *choose_text,
+                                      bool &choose_var,
+                                      const char *buttons,
+                                      char **return_str )
+{
+    return string_request_choose( title, text, default_str, choose_text,
+                                  choose_var, buttons, return_str,
+                                  REQUEST_NONE);
+}
+
+int Requester::string_request_choose( const char *title,
+                                      const char *text,
+                                      const char *default_str,
+                                      const char *choose_text,
+                                      bool &choose_var,
+                                      const char *buttons,
+                                      char **return_str,
+                                      request_flags_t flags )
+{
+    return string_request_choose( title, text, default_str, choose_text,
+                                  choose_var, buttons, return_str, NULL, flags );
+}
+
+int Requester::string_request_choose( const char *title,
+                                      const char *text,
+                                      const char *default_str,
+                                      const char *choose_text,
+                                      bool &choose_var,
+                                      const char *buttons,
+                                      char **return_str,
+                                      const AWindow *twin,
+                                      request_flags_t flags )
+{
+    Button **buts;
+    int nbuttons;
+    char **buttonss;
+    StringGadget *sg;
+    int i;
+  
+    nbuttons=createLines(buttons,&buttonss);
+
+    if ( twin == NULL && transientawin == NULL ) {
+        twin = aguix->getTransientWindow();
+    }
+  
+    AWindow *win = new AWindow( aguix, 10, 10, 10, 10, title, AWindow::AWINDOW_DIALOG );
+    win->create();
+    if ( twin != NULL ) {
+        win->setTransientForAWindow( twin );
+    } else if ( transientawin != NULL ) {
+        win->setTransientForAWindow( transientawin );
+    }
+
+    AContainer *ac1 = win->setContainer( new AContainer( win, 1, 5 ), true );
+    ac1->setMinSpace( 0 );
+    ac1->setMaxSpace( 0 );
+    ac1->setBorderWidth( 5 );
+
+    AContainerBB *ac1_texts = dynamic_cast<AContainerBB*>( ac1->add( new AContainerBB( win, 1, 1 ), 0, 0 ) );
+    ac1_texts->setBorderWidth( 5 );
+    win->addMultiLineText( text, *ac1_texts, 0, 0, NULL, NULL );
+
+    sg = ac1->addWidget( new StringGadget( aguix, 0, 0, 100, default_str, 0 ),
+                         0, 1, AContainer::CO_INCW );
+    sg->setAcceptFocus( true );
+
+    ac1->setMinHeight( 5, 0, 2 );
+
+    AContainer *ac1_2 = ac1->add( new AContainer( win, 1, 1 ), 0, 2 );
+    ac1_2->setMinSpace( 5 );
+    ac1_2->setMaxSpace( -1 );
+    ac1_2->setBorderWidth( 5 );
+
+    ChooseButton *cb1 = ac1_2->addWidget( new ChooseButton( aguix, 0,
+                                                            0, choose_var,
+                                                            choose_text, LABEL_RIGHT, 1 ),
+                                          0, 0, AContainer::CO_INCWNR );
+
+    AContainer *ac1_buttons = NULL;
+
+    if ( nbuttons == 1 ) {
+        ac1_buttons = ac1->add( new AContainer( win, 3, 1 ), 0, 4 );
+        ac1_buttons->setMinSpace( 0 );
+        ac1_buttons->setMaxSpace( 0 );
+    } else {
+        ac1_buttons = ac1->add( new AContainer( win, nbuttons, 1 ), 0, 4 );
+        ac1_buttons->setMinSpace( 5 );
+        ac1_buttons->setMaxSpace( -1 );
+    }
+    ac1_buttons->setBorderWidth( 0 );
+
+    buts = (Button**)_allocsafe( nbuttons * sizeof( Button* ) );
+
+    if ( nbuttons == 1 ) {
+        buts[0] = ac1_buttons->addWidget( new Button( aguix, 0, 0, buttonss[0], 0 ),
+                                          1, 0, AContainer::CO_FIX );
+    } else {
+        for ( i = 0; i < nbuttons; i++ ) {
+            buts[i] = ac1_buttons->addWidget( new Button( aguix, 0, 0, buttonss[i], i ),
+                                              i, 0, AContainer::CO_FIX );
+        }
+    }
+
+    for ( i = 0; i < nbuttons; i++ ) {
+        buts[i]->setAcceptFocus( true );
+    }
+ 
+    sg->setXOffset( 0 );
+    if ( default_str != NULL ) {
+        if ( flags == REQUEST_CURSORLEFT ) {
+            sg->setCursor( 0 );
+        } else if ( flags == REQUEST_CURSORRIGHT ) {
+            sg->setCursor( (int)strlen( default_str ) );
+        } else if ( flags == REQUEST_SELECTALL ) {
+            sg->selectAll();
+        }
+    }
+
+    sg->takeFocus();
+    win->useStippleBackground();
+    win->setDoTabCycling( true );
+    win->contMaximize( true );
+    win->centerScreen();
+    win->show();
+    AGMessage *msg;
+    int endmode=-1;
+    for(;endmode==-1;) {
+        msg=aguix->WaitMessage(win);
+        if(msg!=NULL) {
+            switch(msg->type) {
+                case AG_CLOSEWINDOW:
+                    if ( msg->closewindow.window == win->getWindow() ) {
+                        if ( ( flags & REQUEST_CANCELWITHLEFT ) != 0 ) {
+                            endmode = 0;
+                        } else {
+                            endmode = nbuttons - 1;
+                        }
+                    }
+                    break;
+                case AG_BUTTONCLICKED:
+                    for(i=0;i<nbuttons;i++) {
+                        if(msg->button.button==buts[i]) {
+                            endmode=i;
+                            break;
+                        }
+                    }
+                    break;
+                case AG_STRINGGADGET_OK:
+                    if(msg->stringgadget.sg==sg) endmode=0;
+                    break;
+                case AG_STRINGGADGET_CANCEL:
+                    if ( msg->stringgadget.sg == sg ) {
+                        if ( ( flags & REQUEST_CANCELWITHLEFT ) != 0 ) {
+                            endmode = 0;
+                        } else {
+                            endmode = nbuttons - 1;
+                        }
+                    }
+                    break;
+                case AG_KEYPRESSED:
+                    if ( win->isParent( msg->key.window, false ) == true ) {
+                        // key release only accept when not first key we get
+                        // means a key is pressed when we started and if we use this
+                        // key it could confuse the user
+                        switch(msg->key.key) {
+                            case XK_KP_Enter:
+                            case XK_Return:
+#ifdef ACCEPT_ENTER_FOR_CHOOSE
+                                for ( i = 0; i < nbuttons; i++ ) {
+                                    if ( buts[i]->getHasFocus() == true ) {
+                                        endmode = i;
+                                        break;
+                                    }
+                                }
+#else
+                                if ( buts[0]->hasFocus() == true ) endmode = 0;
+#endif
+                                break;
+                            case XK_Escape:
+                                if ( ( flags & REQUEST_CANCELWITHLEFT ) != 0 ) {
+                                    endmode = 0;
+                                } else {
+                                    endmode = nbuttons - 1;
+                                }
+                                break;
+                            case XK_F1:
+                                endmode=0;
+                                break;
+                            case XK_F2:
+                                endmode=1;
+                                if(endmode>=nbuttons) endmode = -1;
+                                break;
+                            case XK_F3:
+                                endmode=2;
+                                if(endmode>=nbuttons) endmode = -1;
+                                break;
+                            case XK_F4:
+                                endmode=3;
+                                if(endmode>=nbuttons) endmode = -1;
+                                break;
+                            case XK_F5:
+                                endmode=4;
+                                if(endmode>=nbuttons) endmode = -1;
+                                break;
+                            case XK_F6:
+                                endmode=5;
+                                if(endmode>=nbuttons) endmode = -1;
+                                break;
+                            case XK_F7:
+                                endmode=6;
+                                if(endmode>=nbuttons) endmode = -1;
+                                break;
+                            case XK_F8:
+                                endmode=7;
+                                if(endmode>=nbuttons) endmode = -1;
+                                break;
+                            case XK_F9:
+                                endmode=8;
+                                if(endmode>=nbuttons) endmode = -1;
+                                break;
+                            case XK_F10:
+                                endmode=9;
+                                if(endmode>=nbuttons) endmode = -1;
+                                break;
+                            case XK_Left:
+                                win->prevFocus();
+                                break;
+                            case XK_Right:
+                                win->nextFocus();
+                                break;
+                        }
+                    }
+                    break;
+            }
+            aguix->ReplyMessage(msg);
+        }
+    }
+    if ( return_str != NULL ) {
+        *return_str = dupstring( sg->getText() );
+    }
+
+    choose_var = cb1->getState();
+
+    delete win;
+    for(i=0;i<nbuttons;i++) _freesafe(buttonss[i]);
+    _freesafe(buttonss);
+    _freesafe(buts);
+    return endmode;
+}
+
