@@ -24,6 +24,7 @@
 #include "guielement.h"
 #include "utf8.hh"
 #include "drawablecont.hh"
+#include "util.h"
 
 const char *StringGadget::type="StringGadget";
 
@@ -837,12 +838,10 @@ void StringGadget::removeSelection()
 void StringGadget::insertSelection()
 {
   if ( isCreated() == false ) return;
-  char *bytes_return;
 
   if ( _aguix->amiOwner() == true ) {
-    bytes_return = dupstring( _aguix->getCutBuffer() );
-    content.insertAtCursor( bytes_return );
-    _freesafe( bytes_return );
+    std::string s2 = AGUIXUtils::remove_char( _aguix->getCutBuffer(), '\n' );
+    content.insertAtCursor( s2.c_str() );
   } else {
     _aguix->requestCut(getWindow());
     _aguix->startPaste(this);
@@ -956,7 +955,8 @@ void StringGadget::paste(unsigned char*buf)
       content.setSelStart( content.getCursorPos() );
       content.setSelEnd( content.getCursorPos() );
 
-      content.insertAtCursor( (char*)buf );
+      std::string s2 = AGUIXUtils::remove_char( (const char *)buf, '\n' );
+      content.insertAtCursor( s2.c_str() );
       
       redraw();
     }
