@@ -36,7 +36,7 @@ public:
   TVCallBack( const TVCallBack &other );
   TVCallBack &operator=( const TVCallBack &other );
   
-  void run_int( Widget *, int value );
+  void run_int( Widget *, int value ) override;
 private:
   class TextView *tv;
 };
