@@ -121,15 +121,6 @@ namespace AGUIXUtils
         return return_str;
     }
     
-    template <class T>
-    struct my_tolower_func : public std::unary_function< T, T > 
-    {
-        T operator() ( const T& c ) const 
-        {
-            return std::tolower( c );
-        }
-    };
-
     std::string tolower( const std::string &str )
     {
         std::string res( str );
@@ -137,7 +128,7 @@ namespace AGUIXUtils
         std::transform( res.begin(),
                         res.end(),
                         res.begin(),
-                        my_tolower_func<char>() );
+                        [](auto c) { return std::tolower( c ); } );
         return res;
     }
 
