@@ -23,7 +23,7 @@
 #include <fstream>
 #include <sstream>
 #include "aguix/lowlevelfunc.h"
-#include <aguix/util.h>
+#include "aguix/util.h"
 
 using namespace AJSON;
 
@@ -72,7 +72,11 @@ int JSONObject::dump( std::ostream &out, int indent_level )
 
 		out << "\"" << escape_string( k.first ) << "\": ";
 
-		res |= k.second->dump( out, indent_level + 1 );
+        if ( k.second ) {
+            res |= k.second->dump( out, indent_level + 1 );
+        } else {
+            out << "null";
+        }
 
 		if ( pos + 1 < m_elements.size() ) {
 			out << ",";
@@ -124,7 +128,11 @@ int JSONArray::dump( std::ostream &out, int indent_level )
 	for ( size_t pos = 0; pos < m_elements.size(); pos++ ) {
 		output_indentation( out, indent_level + 1 );
 
-		res |= m_elements[pos]->dump( out, indent_level + 1 );
+        if ( m_elements[pos] ) {
+            res |= m_elements[pos]->dump( out, indent_level + 1 );
+        } else {
+            out << "null";
+        }
 
 		if ( pos + 1 < m_elements.size() ) {
 			out << ",";
