@@ -1,6 +1,6 @@
 /* changelayoutop.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2009-2014 Ralf Hoffmann.
+ * Copyright (C) 2009-2021 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -68,7 +68,7 @@ ChangeLayoutOp::getName()
 }
 
 int
-ChangeLayoutOp::run( WPUContext *wpu, ActionMessage *msg )
+ChangeLayoutOp::run( std::shared_ptr< WPUContext > wpu, ActionMessage *msg )
 {
     if ( msg->getWorker()->getUseCustomLayout() == false ) {
         msg->getWorker()->setCustomLayout( m_layout );
@@ -427,6 +427,15 @@ ChangeLayoutOp::configure()
                 case AG_SLIDER_CHANGED:
                     updateWeightSlider();
                     break;
+                case AG_KEYPRESSED:
+                    if ( m_win->isParent( msg->key.window, false ) == true ) {
+                        switch ( msg->key.key ) {
+                            case XK_Escape:
+                                endmode = 1;
+                                break;
+                        }
+                    }
+                    break;
                 default:
                     break;
             }
