@@ -1,6 +1,6 @@
 /* chmodowncore.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2013-2014 Ralf Hoffmann.
+ * Copyright (C) 2013-2021 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -35,6 +35,7 @@
 #include "aguix/awindow.h"
 #include "aguix/acontainer.h"
 #include "aguix/fieldlistview.h"
+#include "aguix/stringgadget.h"
 #include "simplelist.hh"
 
 ChModOwnCore::ChModOwnCore( struct NM_chmodorder *chmodorder,
@@ -89,12 +90,37 @@ int ChModOwnCore::executeChMod()
 {
     changemod_info_t cminfo;
 
+    if ( m_chmodorder ) {
+        switch ( m_chmodorder->apply_mode ) {
+            case CHMOD_SET_PERMISSIONS:
+                cminfo.op = changemod_info_t::CHMOD_SET;
+                cminfo.forAll = true;
+                cminfo.mode = m_chmodorder->permissions;
+                break;
+            case CHMOD_ADD_PERMISSIONS:
+                cminfo.op = changemod_info_t::CHMOD_ADD;
+                cminfo.forAll = true;
+                cminfo.mode = m_chmodorder->permissions;
+                break;
+            case CHMOD_REMOVE_PERMISSIONS:
+                cminfo.op = changemod_info_t::CHMOD_REM;
+                cminfo.forAll = true;
+                cminfo.mode = m_chmodorder->permissions;
+                break;
+            default:
+                break;
+        }
+    }
+
     for ( auto &cbe : m_change_list ) {
         if ( m_cancel ) break;
 
         if ( worker_changemod( cbe, &cminfo ) != 0 ) {
             break;
         }
+        Worker::pushCommandLog( catalog.getLocale( 1417 ),
+                                cbe.entry().fullname,
+                                cbe.entry().fullname );
     }
 
     return 0;
@@ -112,6 +138,9 @@ int ChModOwnCore::executeChOwn()
         if ( worker_changeown( cbe, &coinfo ) != 0 ) {
             break;
         }
+        Worker::pushCommandLog( "change file owner",
+                                cbe.entry().fullname,
+                                cbe.entry().fullname );
     }
 
     freeOwnerRequestInfos();
@@ -388,6 +417,42 @@ static void setChooseButtonMatrixForMode( ChooseButton **mcb, mode_t mode )
     mcb[11]->setState( ( ( mode & S_ISVTX ) == 0 ) ? false : true );
 }
 
+static mode_t getChooseButtonMatrixMode( ChooseButton **mcb )
+{
+    mode_t newmode = 0;
+    newmode |= ( mcb[0]->getState() == true ) ? S_IRUSR : 0;
+    newmode |= ( mcb[1]->getState() == true ) ? S_IWUSR : 0;
+    newmode |= ( mcb[2]->getState() == true ) ? S_IXUSR : 0;
+    newmode |= ( mcb[3]->getState() == true ) ? S_IRGRP : 0;
+    newmode |= ( mcb[4]->getState() == true ) ? S_IWGRP : 0;
+    newmode |= ( mcb[5]->getState() == true ) ? S_IXGRP : 0;
+    newmode |= ( mcb[6]->getState() == true ) ? S_IROTH : 0;
+    newmode |= ( mcb[7]->getState() == true ) ? S_IWOTH : 0;
+    newmode |= ( mcb[8]->getState() == true ) ? S_IXOTH : 0;
+    newmode |= ( mcb[9]->getState() == true ) ? S_ISUID : 0;
+    newmode |= ( mcb[10]->getState() == true ) ? S_ISGID : 0;
+    newmode |= ( mcb[11]->getState() == true ) ? S_ISVTX : 0;
+
+    return newmode;
+}
+
+static void setOctalSGForMode( StringGadget *octal_sg, mode_t permissions )
+{
+    std::string s = AGUIXUtils::formatStringToString( "%o", permissions & 07777 );
+
+    octal_sg->setText( s.c_str() );
+}
+
+static mode_t getModeFromOctalSG( StringGadget *octal_sg )
+{
+    int mode;
+
+    if ( sscanf( octal_sg->getText(), "%o", &mode ) == 1 ) {
+        return (mode_t)mode;
+    }
+    return 0;
+}
+
 int ChModOwnCore::requestNewMode( const FileEntry &fe, changemod_info_t *return_mode )
 {
     mode_t tmode, newmode;
@@ -401,7 +466,7 @@ int ChModOwnCore::requestNewMode( const FileEntry &fe, changemod_info_t *return_
     win = new AWindow( m_aguix, 10, 10, 10, 10, catalog.getLocale( 1279 ), AWindow::AWINDOW_DIALOG );
     win->create();
     
-    AContainer *ac1 = win->setContainer( new AContainer( win, 1, 4 ), true );
+    AContainer *ac1 = win->setContainer( new AContainer( win, 1, 5 ), true );
     ac1->setMinSpace( 5 );
     ac1->setMaxSpace( 5 );
     
@@ -481,9 +546,19 @@ int ChModOwnCore::requestNewMode( const FileEntry &fe, changemod_info_t *return_
     mcb[11] = (ChooseButton*)ac1_2->add( new ChooseButton( m_aguix, 0, 0,
                                                            ( ( tmode & S_ISVTX ) == 0 ) ? 0 : 1,
                                                            "", LABEL_RIGHT, 0 ), 3, 5, AContainer::CO_FIXNR + AContainer::ACONT_CENTER );
+
+    AContainer *ac1_4 = ac1->add( new AContainer( win, 2, 1 ), 0, 3 );
+    ac1_4->setMinSpace( 5 );
+    ac1_4->setMaxSpace( 5 );
+
+    ac1_4->add( new Text( m_aguix, 0, 0, catalog.getLocale( 1405 ) ), 0, 0, AContainer::CO_FIX );
+    auto *octal_sg = ac1_4->addWidget( new StringGadget( m_aguix, 0, 0, 50, "", 0 ),
+                                       1, 0, AContainer::CO_INCW );
+
     setChooseButtonMatrixForMode( mcb, tmode );
+    setOctalSGForMode( octal_sg, tmode );
     
-    AContainer *ac1_3 = ac1->add( new AContainer( win, 4, 1 ), 0, 3 );
+    AContainer *ac1_3 = ac1->add( new AContainer( win, 4, 1 ), 0, 4 );
     ac1_3->setMinSpace( 5 );
     ac1_3->setMaxSpace( -1 );
     ac1_3->setBorderWidth( 0 );
@@ -531,52 +606,62 @@ int ChModOwnCore::requestNewMode( const FileEntry &fe, changemod_info_t *return_
                             case XK_KP_1:
                             case XK_KP_End:
                                 mcb[6]->setState( ( mcb[6]->getState() == true ) ? false : true );
+                                setOctalSGForMode( octal_sg, getChooseButtonMatrixMode( mcb ) );
                                 break;
                             case XK_2:
                             case XK_KP_2:
                             case XK_KP_Down:
                                 mcb[7]->setState( ( mcb[7]->getState() == true ) ? false : true );
+                                setOctalSGForMode( octal_sg, getChooseButtonMatrixMode( mcb ) );
                                 break;
                             case XK_3:
                             case XK_KP_3:
                             case XK_KP_Next:
                                 mcb[8]->setState( ( mcb[8]->getState() == true ) ? false : true );
+                                setOctalSGForMode( octal_sg, getChooseButtonMatrixMode( mcb ) );
                                 break;
                             case XK_4:
                             case XK_KP_4:
                             case XK_KP_Left:
                                 mcb[3]->setState( ( mcb[3]->getState() == true ) ? false : true );
+                                setOctalSGForMode( octal_sg, getChooseButtonMatrixMode( mcb ) );
                                 break;
                             case XK_5:
                             case XK_KP_5:
                             case XK_KP_Begin:
                                 mcb[4]->setState( ( mcb[4]->getState() == true ) ? false : true );
+                                setOctalSGForMode( octal_sg, getChooseButtonMatrixMode( mcb ) );
                                 break;
                             case XK_6:
                             case XK_KP_6:
                             case XK_KP_Right:
                                 mcb[5]->setState( ( mcb[5]->getState() == true ) ? false : true );
+                                setOctalSGForMode( octal_sg, getChooseButtonMatrixMode( mcb ) );
                                 break;
                             case XK_7:
                             case XK_KP_7:
                             case XK_KP_Home:
                                 mcb[0]->setState( ( mcb[0]->getState() == true ) ? false : true );
+                                setOctalSGForMode( octal_sg, getChooseButtonMatrixMode( mcb ) );
                                 break;
                             case XK_8:
                             case XK_KP_8:
                             case XK_KP_Up:
                                 mcb[1]->setState( ( mcb[1]->getState() == true ) ? false : true );
+                                setOctalSGForMode( octal_sg, getChooseButtonMatrixMode( mcb ) );
                                 break;
                             case XK_9:
                             case XK_KP_9:
                             case XK_KP_Prior:
                                 mcb[2]->setState( ( mcb[2]->getState() == true ) ? false : true );
+                                setOctalSGForMode( octal_sg, getChooseButtonMatrixMode( mcb ) );
                                 break;
                             case XK_Return:
                             case XK_KP_Enter:
                                 if ( ok2allb->getHasFocus() == false &&
                                      skipb->getHasFocus() == false &&
-                                     cb->getHasFocus() == false ) {
+                                     cb->getHasFocus() == false &&
+                                     octal_sg->isActive() == false ) {
                                     endmode = 0;
                                 }
                                 break;
@@ -584,6 +669,10 @@ int ChModOwnCore::requestNewMode( const FileEntry &fe, changemod_info_t *return_
                                 endmode = 0;
                                 break;
                             case XK_Escape:
+                                if ( octal_sg->isActive() == false ) {
+                                    endmode = 3;
+                                }
+                                break;
                             case XK_F4:
                                 endmode = 3;
                                 break;
@@ -609,6 +698,21 @@ int ChModOwnCore::requestNewMode( const FileEntry &fe, changemod_info_t *return_
                         }
                     }
                     break;
+                case AG_STRINGGADGET_OK:
+                    if ( msg->stringgadget.sg == octal_sg ) {
+                        mode_t m = getModeFromOctalSG( octal_sg );
+                        setChooseButtonMatrixForMode( mcb, m );
+                    }
+                    break;
+                case AG_STRINGGADGET_CANCEL:
+                    if ( msg->stringgadget.sg == octal_sg ) {
+                        mode_t m = getChooseButtonMatrixMode( mcb );
+                        setOctalSGForMode( octal_sg, m );
+                    }
+                    break;
+                case AG_CHOOSECLICKED:
+                    setOctalSGForMode( octal_sg, getChooseButtonMatrixMode( mcb ) );
+                    break;
             }
             m_aguix->ReplyMessage( msg );
         }
