@@ -1,6 +1,6 @@
 /* chtimecore.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2015-2016 Ralf Hoffmann.
+ * Copyright (C) 2015-2021 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -90,6 +90,9 @@ int ChTimeCore::execute()
         if ( worker_changetime( cbe, &ctinfo ) != 0 ) {
             break;
         }
+        Worker::pushCommandLog( catalog.getLocale( 1418 ),
+                                cbe.entry().fullname,
+                                cbe.entry().fullname );
     }
 
     return 0;
