@@ -1,6 +1,6 @@
 /* clipboardop.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2012-2014 Ralf Hoffmann.
+ * Copyright (C) 2012-2021 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -72,7 +72,7 @@ ClipboardOp::getName()
 }
 
 int
-ClipboardOp::run( WPUContext *wpu, ActionMessage *msg )
+ClipboardOp::run( std::shared_ptr< WPUContext > wpu, ActionMessage *msg )
 {
     std::string res_str;
     if ( wpu->parse( m_string.c_str(),
