@@ -1,6 +1,6 @@
 /* configtokens.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2003-2021 Ralf Hoffmann.
+ * Copyright (C) 2003-2022 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -467,7 +467,8 @@ struct mytoken tokenlist[]={
   { ADD_WCP, "add" },
   { REMOVE_WCP, "remove" },
   { HIDENONEXISTING_WCP, "hidenonexisting" },
-  { VIEWCOMMANDLOGOP_WCP, "viewcommandlogop" }
+  { VIEWCOMMANDLOGOP_WCP, "viewcommandlogop" },
+  { LOCKONCURRENTDIR_WCP, "lockoncurrentdir" }
 };
 
 ArrayList *tokenlist_sorted = NULL;
