@@ -1,6 +1,6 @@
 /* copycore.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2013-2017 Ralf Hoffmann.
+ * Copyright (C) 2013-2021 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -33,6 +33,7 @@
 #include <ratio>
 #include "nwc_path.hh"
 #include "nwc_os.hh"
+#include "worker.h"
 
 CopyCore::CopyCore( std::shared_ptr< struct copyorder > co ) :
     m_copyorder( co ),
@@ -1853,6 +1854,11 @@ int CopyCore::executeCopyThread()
                 ce1 = copydir( &cbe.entry(), tcod, true, destdir.c_str(), &target_fullname );
                 if ( ce1 == NM_COPY_OK || ce1 == NM_COPY_NEED_DELETE ) {
                     // success
+                    Worker::pushCommandLog( m_copyorder->move ? catalog.getLocale( 1420 ) : catalog.getLocale( 1419 ),
+                                            target_fullname,
+                                            AGUIXUtils::formatStringToString( catalog.getLocale( 1421 ),
+                                                                              cbe.entry().fullname,
+                                                                              destdir.c_str() ) );
                 } else if ( ce1 == NM_COPY_CANCEL ) {
                     m_cancel = true;
                 }
@@ -1883,6 +1889,11 @@ int CopyCore::executeCopyThread()
 
                 if ( ce1 == NM_COPY_OK || ce1 == NM_COPY_NEED_DELETE ) {
                     // success
+                    Worker::pushCommandLog( m_copyorder->move ? catalog.getLocale( 1420 ) : catalog.getLocale( 1419 ),
+                                            target_fullname,
+                                            AGUIXUtils::formatStringToString( catalog.getLocale( 1421 ),
+                                                                              cbe.entry().fullname,
+                                                                              destdir.c_str() ) );
                 } else if ( ce1 == NM_COPY_CANCEL ) {
                     m_cancel = true;
                 }
