@@ -20,7 +20,7 @@
  */
 
 #include "copyorder.hh"
-#include <aguix/lowlevelfunc.h>
+#include "aguix/lowlevelfunc.h"
 #include "nmspecialsourceext.hh"
 #include "copyopwin.hh"
 
