@@ -1,6 +1,6 @@
 /* datei.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2020 Ralf Hoffmann.
+ * Copyright (C) 2001-2022 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -28,6 +28,7 @@
 #include "nwc_os.hh"
 #include "nwc_path.hh"
 #include "worker.h"
+#include "error_count.hh"
 
 Datei::Datei()
 {
@@ -330,8 +331,10 @@ int Datei::getString(char *buf,int count)
 bool Datei::fileExists(const char *name)
 {
   worker_struct_stat stbuf;
-  if ( worker_lstat( name, &stbuf ) != 0 ) return false;
-  else {
+  if ( worker_lstat( name, &stbuf ) != 0 ) {
+      ErrorCount::account_errno( errno );
+      return false;
+  } else {
     /* kann auch verzeichnis sein */
 //    if(S_ISDIR(stbuf.st_mode)) return false;
   }
@@ -342,8 +345,10 @@ Datei::d_fe_t Datei::fileExistsExt(const char*name)
 {
   worker_struct_stat stbuf;
   d_fe_t return_value;
-  if ( worker_stat( name, &stbuf ) != 0 ) return_value = D_FE_NOFILE;
-  else {
+  if ( worker_stat( name, &stbuf ) != 0 ) {
+      ErrorCount::account_errno( errno );
+      return_value = D_FE_NOFILE;
+  } else {
     if(S_ISDIR(stbuf.st_mode)) return_value=D_FE_DIR;
     else return_value=D_FE_FILE;
     if(S_ISLNK(stbuf.st_mode)) return_value=D_FE_LINK;
@@ -355,8 +360,10 @@ Datei::d_fe_t Datei::lfileExistsExt(const char*name)
 {
   worker_struct_stat stbuf;
   d_fe_t return_value;
-  if ( worker_lstat( name, &stbuf ) != 0 ) return_value = D_FE_NOFILE;
-  else {
+  if ( worker_lstat( name, &stbuf ) != 0 ) {
+      ErrorCount::account_errno( errno );
+      return_value = D_FE_NOFILE;
+  } else {
     if(S_ISDIR(stbuf.st_mode)) return_value=D_FE_DIR;
     else return_value=D_FE_FILE;
     if(S_ISLNK(stbuf.st_mode)) return_value=D_FE_LINK;
@@ -851,8 +858,10 @@ loff_t Datei::fileSize( const char *name )
   worker_struct_stat stbuf;
   loff_t return_value;
 
-  if ( worker_stat( name, &stbuf ) != 0 ) return_value = -1;
-  else {
+  if ( worker_stat( name, &stbuf ) != 0 ) {
+      return_value = -1;
+      ErrorCount::account_errno( errno );
+  } else {
     return_value = stbuf.st_size;
   }
   return return_value;
@@ -1048,10 +1057,11 @@ int Datei::getCharacter()
 }
 
 int Datei::copyfile( const char *dest, const char *source,
-                     CopyfileProgressCallback *progress_callback )
+                     CopyfileProgressCallback *progress_callback,
+                     bool follow_symlinks )
 {
   int fdw,fdr;
-  bool useregcopy, cancel, follow_symlinks, isCorrupt;
+  bool useregcopy, cancel, isCorrupt;
   ssize_t readbytes,writebytes;
 #define BUFSIZE ( 4 * 1024 )
   char *buf[BUFSIZE];
@@ -1061,7 +1071,6 @@ int Datei::copyfile( const char *dest, const char *source,
 
   if ( ( dest == NULL ) || ( source == NULL ) ) return 1;
   
-  follow_symlinks = false;
   isCorrupt = false;
   cancel = false;
 
@@ -1070,7 +1079,10 @@ int Datei::copyfile( const char *dest, const char *source,
 
   // get stat for destination if link (will fail for corrupt links)
   // but currently I don't handle them anyway
-  if ( worker_stat( source, &dst ) != 0 ) return 1;
+  if ( worker_stat( source, &dst ) != 0 ) {
+      //isCorrupt = true;
+      return 1;
+  }
   
   useregcopy = false;
   if ( S_ISREG( st.st_mode ) ) {
@@ -1119,8 +1131,10 @@ int Datei::copyfile( const char *dest, const char *source,
       bytes_copied += writebytes;
 
       if ( progress_callback != NULL ) {
-          progress_callback->progress_callback( bytes_copied,
-                                                total_bytes );
+          if ( progress_callback->progress_callback( bytes_copied,
+                                                     total_bytes ) == CopyfileProgressCallback::COPYFILE_ABORT ) {
+              cancel = true;
+          }
       }
     }
   } while ( ( readbytes > 0 ) &&
