@@ -1,6 +1,6 @@
 /* deletecore.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2013 Ralf Hoffmann.
+ * Copyright (C) 2013-2021 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -28,6 +28,7 @@
 #include "verzeichnis.hh"
 #include "aguix/lowlevelfunc.h"
 #include "aguix/util.h"
+#include "worker.h"
 
 DeleteCore::DeleteCore( struct deleteorder *delorder ) :
     m_delorder( delorder ),
@@ -172,6 +173,10 @@ int DeleteCore::executeDelete()
                 ce1 = deldir( &cbe.entry(), tcod, m_delorder );
                 if ( ce1 == DeleteCore::NM_DELETE_CANCEL ) {
                     m_cancel = true;
+                } else if ( ce1 == DeleteCore::NM_DELETE_OK ) {
+                    Worker::pushCommandLog( catalog.getLocale( 1422 ),
+                                            cbe.entry().fullname,
+                                            cbe.entry().fullname );
                 }
             } else {
 
@@ -191,6 +196,10 @@ int DeleteCore::executeDelete()
             ce1 = delfile( &cbe.entry(), m_delorder, false );
             if ( ce1 == DeleteCore::NM_DELETE_CANCEL ) {
                 m_cancel = true;
+            } else if ( ce1 == DeleteCore::NM_DELETE_OK ) {
+                Worker::pushCommandLog( catalog.getLocale( 1422 ),
+                                        cbe.entry().fullname,
+                                        cbe.entry().fullname );
             }
 
             if ( m_post_cb ) {
