@@ -1,6 +1,6 @@
 /* dircompareop.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2017-2021 Ralf Hoffmann.
+ * Copyright (C) 2017-2022 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -28,6 +28,7 @@
 #include "aguix/cyclebutton.h"
 #include "aguix/acontainerbb.h"
 #include "aguix/textview.h"
+#include "aguix/choosebutton.h"
 #include "datei.h"
 #include "worker_locale.h"
 #include "virtualdirmode.hh"
@@ -253,8 +254,15 @@ int DirCompareOp::key_compare( const compare_element &lhs,
     } else if ( lhs.entry->isReg() && ! rhs.entry->isReg() ) {
         return 1;
     } else if ( ! lhs.entry->isReg() && ! rhs.entry->isReg() ) {
-        return StringComparator::compare( lhs.basename,
-                                          rhs.basename );
+        if ( key == FILENAME_IGNORE_CASE ) {
+            return StringComparator::compare( lhs.basename,
+                                              rhs.basename,
+                                              StringComparator::STRING_COMPARE_STRICT_NOCASE);
+        } else {
+            return StringComparator::compare( lhs.basename,
+                                              rhs.basename,
+                                              StringComparator::STRING_COMPARE_REGULAR );
+        }
     }
 
     // both are regular files
@@ -274,8 +282,15 @@ int DirCompareOp::key_compare( const compare_element &lhs,
 #endif
         }
     } else {
-        return StringComparator::compare( lhs.basename,
-                                          rhs.basename );
+        if ( key == FILENAME_IGNORE_CASE ) {
+            return StringComparator::compare( lhs.basename,
+                                              rhs.basename,
+                                              StringComparator::STRING_COMPARE_STRICT_NOCASE);
+        } else {
+            return StringComparator::compare( lhs.basename,
+                                              rhs.basename,
+                                              StringComparator::STRING_COMPARE_REGULAR );
+        }
     }
 }
 
@@ -453,7 +468,7 @@ int DirCompareOp::compareDirs( std::shared_ptr< NWC::Dir > my_dir,
             cmp_key = FILESIZE_CHECKSUM;
             break;
         default:
-            cmp_key = FILENAME;
+            cmp_key = m_ignore_file_name_case ? FILENAME_IGNORE_CASE : FILENAME;
     }
 
     if ( m_compare_mode == COMPARE_CHECKSUM ) {
@@ -748,6 +763,33 @@ DirCompareOp::getDescription()
     return catalog.getLocale( 1307 );
 }
 
+static void check_visibility( int option,
+                              AContainer *limit_cont,
+                              ChooseButton *ignorecase_cb )
+{
+    switch ( option ) {
+        case 3:
+        case 5:
+            limit_cont->show();
+            break;
+        default:
+            limit_cont->hide();
+            break;
+    }
+
+    switch ( option ) {
+        case 0:
+        case 1:
+        case 2:
+        case 3:
+            ignorecase_cb->show();
+            break;
+        default:
+            ignorecase_cb->hide();
+            break;
+    }
+}
+
 int
 DirCompareOp::doConfigure()
 {
@@ -760,7 +802,7 @@ DirCompareOp::doConfigure()
     AWindow *win = new AWindow( aguix, 10, 10, 10, 10, title.c_str(), AWindow::AWINDOW_DIALOG );
     win->create();
     
-    AContainer *ac0 = win->setContainer( new AContainer( win, 1, 5 ), true );
+    AContainer *ac0 = win->setContainer( new AContainer( win, 1, 6 ), true );
     ac0->setMinSpace( 5 );
     ac0->setMaxSpace( 5 );
     ac0->setBorderWidth( 5 );
@@ -799,7 +841,12 @@ DirCompareOp::doConfigure()
     comparemode_cb->resize( comparemode_cb->getMaxSize(),
                            comparemode_cb->getHeight() );
 
-    AContainer *ac1_2 = ac0->add( new AContainer( win, 2, 1 ), 0, 2 );
+    ChooseButton *ignorecase_cb = ac0->addWidget( new ChooseButton( aguix, 0, 0,
+                                                                    false, catalog.getLocale( 1441 ),
+                                                                    LABEL_RIGHT, 0 ),
+                                                  0, 2, AContainer::CO_INCWNR );
+
+    AContainer *ac1_2 = ac0->add( new AContainer( win, 2, 1 ), 0, 3 );
     ac1_2->setMinSpace( 5 );
     ac1_2->setMaxSpace( 5 );
     ac1_2->setBorderWidth( 0 );
@@ -813,7 +860,7 @@ DirCompareOp::doConfigure()
                            resultmode_cb->getHeight() );
     ac0->readLimits();
     
-    AContainer *ac1_4 = ac0->add( new AContainer( win, 2, 1 ), 0, 3 );
+    AContainer *ac1_4 = ac0->add( new AContainer( win, 2, 1 ), 0, 4 );
     ac1_4->setMinSpace( 5 );
     ac1_4->setMaxSpace( 5 );
     ac1_4->setBorderWidth( 0 );
@@ -822,7 +869,7 @@ DirCompareOp::doConfigure()
     StringGadget *limit_sg = ac1_4->addWidget( new StringGadget( aguix, 0, 0, 50, "", 0 ),
                                                1, 0, AContainer::CO_INCW );
 
-    AContainer *ac1_3 = ac0->add( new AContainer( win, 2, 1 ), 0, 4 );
+    AContainer *ac1_3 = ac0->add( new AContainer( win, 2, 1 ), 0, 5 );
     ac1_3->setMinSpace( 5 );
     ac1_3->setMaxSpace( -1 );
     ac1_3->setBorderWidth( 0 );
@@ -841,6 +888,10 @@ DirCompareOp::doConfigure()
     win->contMaximize( true );
     win->show();
 
+    check_visibility( comparemode_cb->getSelectedOption(),
+                      ac1_4,
+                      ignorecase_cb );
+
     for ( ; endmode == -1; ) {
         msg = aguix->WaitMessage( win );
         if ( msg != NULL ) {
@@ -851,6 +902,12 @@ DirCompareOp::doConfigure()
                 case AG_BUTTONCLICKED:
                     if ( msg->button.button == okb ) endmode = 0;
                     else if ( msg->button.button == cb ) endmode = 1;
+                case AG_CYCLEBUTTONCLICKED:
+                    if ( msg->cyclebutton.cyclebutton == comparemode_cb ) {
+                        check_visibility( msg->cyclebutton.option,
+                                          ac1_4,
+                                          ignorecase_cb );
+                    }
                 default:
                     break;
             }
@@ -891,8 +948,12 @@ DirCompareOp::doConfigure()
                 break;
         }
 
+        m_ignore_file_name_case = ignorecase_cb->getState();
+
         if ( strlen( limit_sg->getText() ) > 0 ) {
             m_file_size_limit = AGUIXUtils::convertHumanStringToNumber( limit_sg->getText() );
+        } else {
+            m_file_size_limit = 0;
         }
     }
 
