@@ -1,6 +1,6 @@
 /* fileentry.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2020 Ralf Hoffmann.
+ * Copyright (C) 2001-2022 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -32,6 +32,7 @@
 #include "magic_db.hh"
 #include "worker.h"
 #include "nwc_os.hh"
+#include "error_count.hh"
 
 class FEBookmarkInfo {
 public:
@@ -179,6 +180,7 @@ int FileEntry::readInfos( bool update )
         statbuf.rdev = stbuf.st_rdev;
         statbuf.dev = stbuf.st_dev;
     } else {
+        ErrorCount::account_errno( errno );
         isCorrupt = true;
         return 2;
     }
@@ -200,6 +202,7 @@ int FileEntry::readInfos( bool update )
             dstatbuf.dev = stbuf.st_dev;
         } else {
             /* corrupt link */
+            ErrorCount::account_errno( errno );
             isCorrupt = true;
             dstatbuf.mode = 0;  // to prevent corrupt links treated as dirs
             if ( errno == ENOENT ) {
