@@ -511,7 +511,7 @@ int FileViewerBG::buildTextView( const std::string &filename,
     ts = new TextStorageFile( filename, lencalc, initial_size, TextStorageString::CONVERT_NON_PRINTABLE_SIMPLE );
     tv = new TextView( aguix, 0, 0, 100, 100, "", *ts );
 
-    ts_search = new SearchTextStorage( *ts );
+    ts_search.reset( new SearchTextStorage( *ts ) );
 
     tv->setDisplayFocus( true );
     tv->setFont( wconfig->getFont( 4 ).c_str() );
