@@ -1,6 +1,6 @@
 /* flagreplacer.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2006-2014 Ralf Hoffmann.
+ * Copyright (C) 2006-2021 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -28,8 +28,9 @@
 #include "worker.h"
 #include "worker_locale.h"
 
-FlagReplacer::FlagReplacer( FlagProducer &flagstore ) : _flagstore( flagstore ),
-                                                        m_replace_errors( 0 )
+FlagReplacer::FlagReplacer( std::shared_ptr< FlagProducer > flagstore )
+    : m_flagstore( flagstore ),
+      m_replace_errors( 0 )
 {
 }
 
@@ -115,8 +116,8 @@ std::string FlagReplacer::replaceFlags( const std::string &str, bool quote )
         buf1 = flagbuf.c_str();
       }
       // parse buf1
-      if ( _flagstore.hasFlag( buf1 ) == true ) {
-        std::string replacementstr = _flagstore.getFlagReplacement( buf1 );
+      if ( m_flagstore && m_flagstore->hasFlag( buf1 ) == true ) {
+        std::string replacementstr = m_flagstore->getFlagReplacement( buf1 );
         if ( ( quote == true ) && ( force_noquoting == false ) ) {
           char *newdstr = AGUIX_catTrustedAndUnTrusted( dstr.c_str(), replacementstr.c_str() );
           dstr = newdstr;
@@ -291,3 +292,35 @@ int FlagReplacer::failed_flag_replacements()
 {
     return m_replace_errors;
 }
+
+FlagReplacer::FlagProducerCallback::FlagProducerCallback( void *user_data )
+    : m_user_data( user_data )
+{
+}
+
+FlagReplacer::FlagProducerCallback::~FlagProducerCallback()
+{
+}
+
+std::string FlagReplacer::FlagProducerCallback::getFlagReplacement( const std::string &flag )
+{
+    if ( m_flag_values.count( flag ) == 0 ) {
+        return "";
+    }
+
+    return m_flag_values[ flag ]( m_user_data );
+}
+
+bool FlagReplacer::FlagProducerCallback::hasFlag( const std::string &flag )
+{
+    if ( m_flag_values.count( flag ) > 0 ) {
+        return true;
+    }
+    return false;
+}
+
+void FlagReplacer::FlagProducerCallback::registerFlag( const std::string &flag,
+                                                       std::function< std::string( void *user_data ) > callback )
+{
+    m_flag_values[ flag ] = callback;
+}
