@@ -1,6 +1,6 @@
 /* functionproto.h
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2020 Ralf Hoffmann.
+ * Copyright (C) 2001-2021 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -95,7 +95,7 @@ public:
   virtual bool isName(const char *);
   virtual const char *getName();
   virtual bool save(Datei *);
-  virtual int run( WPUContext *, ActionMessage * );
+  virtual int run( std::shared_ptr< WPUContext >, ActionMessage * );
   virtual const char *getDescription();
   
   static int presave(Datei*,FunctionProto*);
@@ -120,9 +120,13 @@ public:
 
     virtual bool isInteractiveRun() const;
     virtual void setInteractiveRun();
+
+    virtual bool requestParameters() const;
+    virtual void setRequestParameters( bool nv );
 protected:
   static const char *name;
   bool hasConfigure;
+  bool m_request_parameters = false;
   command_categories_t m_category;
 };
 
