@@ -1,6 +1,6 @@
 /* listermode.h
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2019 Ralf Hoffmann.
+ * Copyright (C) 2001-2021 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -101,7 +101,8 @@ public:
     virtual void not_supported();
 
     virtual std::list< WorkerTypes::reg_command_info_t > getListOfCommandsWithoutArgs() const;
-    virtual WorkerTypes::reg_command_info_t getCommandInfo( const std::string &command ) const;
+    virtual std::list< WorkerTypes::reg_command_info_t > getListOfCommandsWithArgs() const;
+    virtual WorkerTypes::reg_command_info_t getCommandInfo( const std::string &command, bool args ) const;
 
     virtual void finalizeBGOps();
 protected:
@@ -113,8 +114,9 @@ protected:
 private:
     std::map< std::string, std::function< void( void ) > > m_commands;
     std::map< std::string, std::function< void ( const std::list< RefCount< ArgClass > > ) > > m_commands_with_args;
-    std::map< std::string, std::tuple< std::string,
-                                       FunctionProto::command_categories_t > > m_command_info;
+    std::map< std::pair< std::string, bool >,
+              std::tuple< std::string,
+                          FunctionProto::command_categories_t > > m_command_info;
 };
 
 #endif
