@@ -580,7 +580,7 @@ void MenuTreeUI::showMenu()
                                 } );
     }
     
-    for ( const auto it1 : m_current_entries ) {
+    for ( const auto &it1 : m_current_entries ) {
         int row1 = m_lv->addRow();
         m_lv_help->addRow();
         m_lv_key->addRow();
@@ -622,7 +622,7 @@ void MenuTreeUI::highlightEntry( const MenuTreeNode *entry )
 
     int row = 0;
 
-    for ( const auto it1 : m_current_entries ) {
+    for ( const auto &it1 : m_current_entries ) {
 
         if ( std::get< 1 >( it1 ) == entry ) {
             m_lv->setActiveRow( row );
