@@ -20,7 +20,7 @@
  */
 
 #include "nmexternfe.hh"
-#include <aguix/lowlevelfunc.h>
+#include "aguix/lowlevelfunc.h"
 #include "datei.h"
 #include "fileentry.hh"
 
