@@ -1,6 +1,6 @@
 /* nwc_path.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2006-2014 Ralf Hoffmann.
+ * Copyright (C) 2006-2021 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -37,11 +37,15 @@ namespace NWC {
                 if ( res[l - 1] != '/' ) {
                     res += "/";
                 }
-            } else {
-                res += "/";
             }
-      
-            res += p2;
+
+            if ( ! p2.empty() &&
+                 p2[0] == '/' ) {
+                res = p2;
+            } else {
+                res += p2;
+            }
+
             return res;
         }
 
@@ -73,8 +77,9 @@ namespace NWC {
         std::string dirname( const std::string &path )
         {
             std::string::size_type pos = path.rfind( "/" );
-            if ( pos == std::string::npos )
-                return std::string( "." );
+            if ( pos == std::string::npos ) {
+                return std::string( "" );
+            }
           
             if ( pos == 0 ) pos++;
 
@@ -377,5 +382,16 @@ namespace NWC {
             
             return res;
         }
+
+        std::string get_last_local_path( const std::string &path )
+        {
+            if ( path.empty() ) return path;
+
+            if ( worker_islocal( path.c_str() ) == 1 ) {
+                return path;
+            }
+
+            return get_last_local_path( dirname( path ) );
+        }
     }
 }
