@@ -47,7 +47,7 @@ NWCEntrySelectionState::NWCEntrySelectionState( const NWCEntrySelectionState &ot
       m_mime_type( other.m_mime_type )
 {
     if ( other.m_bookmark_info.get() != NULL ) {
-        m_bookmark_info = new NWCBookmarkInfo( *other.m_bookmark_info );
+        m_bookmark_info.reset( new NWCBookmarkInfo( *other.m_bookmark_info ) );
     }
 }
 
@@ -64,7 +64,7 @@ NWCEntrySelectionState::NWCEntrySelectionState( const NWCEntrySelectionState &ot
         const NWC::FSEntry *fse = other.getNWCEntry();
 
         if ( fse ) {
-            m_cloned_entry = fse->clone();
+            m_cloned_entry.reset( fse->clone() );
         }
     } else {
         m_dir = other.m_dir;
@@ -72,7 +72,7 @@ NWCEntrySelectionState::NWCEntrySelectionState( const NWCEntrySelectionState &ot
     }
 
     if ( other.m_bookmark_info.get() != NULL ) {
-        m_bookmark_info = new NWCBookmarkInfo( *other.m_bookmark_info );
+        m_bookmark_info.reset( new NWCBookmarkInfo( *other.m_bookmark_info ) );
     }
 }
 
@@ -90,7 +90,7 @@ NWCEntrySelectionState &NWCEntrySelectionState::operator=( const NWCEntrySelecti
         m_mime_type = rhs.m_mime_type;
 
         if ( rhs.m_bookmark_info.get() != NULL ) {
-            m_bookmark_info = new NWCBookmarkInfo( *rhs.m_bookmark_info );
+            m_bookmark_info.reset( new NWCBookmarkInfo( *rhs.m_bookmark_info ) );
         } else {
             m_bookmark_info = NULL;
         }
@@ -352,7 +352,7 @@ void NWCEntrySelectionState::setMatchingLabels( const std::list<std::string> &la
         }
     } else {
         if ( ! m_bookmark_info.get() ) {
-            m_bookmark_info = new NWCBookmarkInfo();
+            m_bookmark_info.reset( new NWCBookmarkInfo() );
         }
 
         m_bookmark_info->m_matching_labels = labels;
@@ -400,7 +400,7 @@ void NWCEntrySelectionState::setBookmarkMatch( FileEntry::bookmark_match_t m )
         }
     } else {
         if ( m_bookmark_info.get() == NULL ) {
-            m_bookmark_info = new NWCBookmarkInfo();
+            m_bookmark_info.reset( new NWCBookmarkInfo() );
         }
 
         m_bookmark_info->m_bookmark_match = m;
