@@ -682,13 +682,13 @@ void OwnOp::externprog( std::shared_ptr< WPUContext > wpu, ActionMessage *msg )
       
         if ( ownstart == OWNOP_SHOW_OUTPUT_INT ) {
             tmpoutput_lnk = Datei::createTMPHardlink( tmpoutput );
-            pea = new ProcessExitAction( true,
-                                         tmpoutput_lnk,
-                                         msg->getWorker(), wpu );
+            pea.reset( new ProcessExitAction( true,
+                                              tmpoutput_lnk,
+                                              msg->getWorker(), wpu ) );
         } else {
-            pea = new ProcessExitAction( false,
-                                         "",
-                                         msg->getWorker(), wpu );
+            pea.reset( new ProcessExitAction( false,
+                                              "",
+                                              msg->getWorker(), wpu ) );
         }
 
         fp = new Datei();
@@ -798,7 +798,7 @@ void OwnOp::externprog( std::shared_ptr< WPUContext > wpu, ActionMessage *msg )
             worker_unlink( tmpname );
             worker_unlink( tmpoutput );
 
-            if ( pea.getVal() != NULL ) {
+            if ( pea.get() != NULL ) {
                 pea->callback( 0 );
             }
         }
