@@ -1,6 +1,6 @@
 /* ownop.h
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2005,2010-2011,2013 Ralf Hoffmann.
+ * Copyright (C) 2001-2021 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -86,16 +86,15 @@ public:
   OwnOp( const OwnOp &other );
   OwnOp &operator=( const OwnOp &other );
 
-  virtual OwnOp *duplicate() const;
-  virtual bool isName(const char *);
-  virtual const char *getName();
+  OwnOp *duplicate() const override;
+  bool isName(const char *) override;
+  const char *getName() override;
 
-  using FunctionProto::run;
-  virtual int run( WPUContext *, ActionMessage * );
+  int run( std::shared_ptr< WPUContext > wpu, ActionMessage * ) override;
 
-  virtual bool save(Datei*);
-  virtual const char *getDescription();
-  virtual int configure();
+  bool save(Datei*) override;
+  const char *getDescription() override;
+  int configure() override;
 
   typedef enum {OWNOP_START_NORMAL=0,
                 OWNOP_START_IN_TERMINAL,
@@ -133,7 +132,7 @@ protected:
     bool m_use_virtual_temp_copies;
     bool m_flags_are_relative_to_base_dir;
   
-    void externprog( class WPUContext *wpu, ActionMessage *msg );
+    void externprog( std::shared_ptr< WPUContext > wpu, ActionMessage *msg );
 };
 
 #endif
