@@ -1,6 +1,6 @@
 /* scriptop.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2002-2014 Ralf Hoffmann.
+ * Copyright (C) 2002-2021 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -112,7 +112,7 @@ ScriptOp::getName()
 }
 
 int
-ScriptOp::run( WPUContext *wpu, ActionMessage *msg )
+ScriptOp::run( std::shared_ptr< WPUContext > wpu, ActionMessage *msg )
 {
   char *tstr2, *tstr3;
   int erg, l, exeerror = 1;
@@ -472,7 +472,7 @@ ScriptOp::getDescription()
         AGUIXUtils::split_string( v, m_command_str, ' ' );
 
         if ( ! v.empty() ) {
-            auto res = wconfig->getWorker()->getCommandInfo( v[0] );
+            auto res = wconfig->getWorker()->getCommandInfo( v[0], v.size() == 1 ? false : true );
 
             if ( ! res.name.empty() ) {
                 str1 += " (";
@@ -1204,6 +1204,15 @@ int ScriptOp::configure()
 	    }
           }
           break;
+          case AG_KEYPRESSED:
+            if ( win->isParent( msg->key.window, false ) == true ) {
+                switch ( msg->key.key ) {
+                    case XK_Escape:
+                        endmode = 1;
+                        break;
+                }
+            }
+            break;
       }
       aguix->ReplyMessage(msg);
     }
@@ -1511,20 +1520,21 @@ char *ScriptOp::getRegisteredCommand()
   lv = (FieldListView*)ac1->add( new FieldListView( aguix,
                                                     0,
                                                     0,
-                                                    400,
+                                                    600,
                                                     300,
                                                     0 ),
                                  0, 1, AContainer::CO_MIN );
   lv->setHBarState(2);
   lv->setVBarState(2);
   lv->setDefaultColorMode( FieldListView::PRECOLOR_ONLYACTIVE );
-  lv->setNrOfFields( 2 );
+  lv->setNrOfFields( 3 );
   lv->setGlobalFieldSpace( 5 );
   lv->setDisplayFocus( true );
   lv->setAcceptFocus( true );
   lv->setShowHeader( true );
   lv->setFieldText( 0, catalog.getLocale( 951 ) );
   lv->setFieldText( 1, catalog.getLocale( 1319 ) );
+  lv->setFieldText( 2, catalog.getLocale( 1391 ) );
 
   {
       Lister *l1 = wconfig->getWorker()->getLister( 0 );
@@ -1534,11 +1544,25 @@ char *ScriptOp::getRegisteredCommand()
 
           if ( lm1 != NULL ) {
               auto l = lm1->getListOfCommandsWithoutArgs();
+              for ( auto &e : lm1->getListOfCommandsWithArgs() ) {
+                  l.push_back( e );
+              }
+
+              l.sort( []( const auto &lhs,
+                          const auto &rhs ) {
+                  return lhs.name < rhs.name;
+              } );
 
               for ( auto &e : l ) {
                   int trow = lv->addRow();
                   lv->setText( trow, 0, e.name );
                   lv->setText( trow, 1, e.description );
+
+                  if ( e.has_args ) {
+                      lv->setText( trow, 2, catalog.getLocale( 801 ) );
+                  } else {
+                      lv->setText( trow, 2, catalog.getLocale( 802 ) );
+                  }
               }
           }
       }
