@@ -1,6 +1,6 @@
 /* searchentryop.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2014 Ralf Hoffmann.
+ * Copyright (C) 2001-2021 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -68,7 +68,7 @@ SearchEntryOp::getName()
 }
 
 int
-SearchEntryOp::run( WPUContext *wpu, ActionMessage *msg )
+SearchEntryOp::run( std::shared_ptr< WPUContext > wpu, ActionMessage *msg )
 {
   ListerMode *lm1;
   if(msg->mode!=msg->AM_MODE_DNDACTION) {
@@ -214,6 +214,15 @@ int SearchEntryOp::configure()
       } else if ( msg->type == AG_BUTTONCLICKED ) {
         if ( msg->button.button == okb ) ende = 1;
         else if ( msg->button.button == cancelb ) ende = -1;
+      } else if ( msg->type == AG_KEYPRESSED ) {
+          if ( win->isParent( msg->key.window, false ) == true ) {
+              switch ( msg->key.key ) {
+                  case XK_Escape:
+                      ende = -1;
+                      break;
+              }
+          }
+          break;
       }
       aguix->ReplyMessage( msg );
     }
