@@ -221,7 +221,7 @@ int SearchThread::prepareDirWalk( const NWC::Dir &dir, NWC::Dir::WalkControlObj
                                                                     vdir.getSearchSameFS() );
                         if ( vd->entryExists() == true && vd->isDir() ) {
                             vd->setVirtualDepthCount( vdir.getVirtualDepthCount() + 1 );
-                            return_add_entries.push_back( vd );
+                            return_add_entries.push_back( RefCount< NWC::FSEntry >( vd ) );
                         }
                     }
                 }
