@@ -249,13 +249,13 @@ StartProgOp::startprog( std::shared_ptr< WPUContext > wpu, ActionMessage *am )
       if ( m1->_start == STARTPROGOP_SHOW_OUTPUT_INT ) {
           tmpoutput_lnk = Datei::createTMPHardlink( tmpoutput );
 
-          pea = new ProcessExitAction( true,
-                                       tmpoutput_lnk,
-                                       am->getWorker(), wpu );
+          pea.reset( new ProcessExitAction( true,
+                                            tmpoutput_lnk,
+                                            am->getWorker(), wpu ) );
       } else {
-          pea = new ProcessExitAction( false,
-                                       "",
-                                       am->getWorker(), wpu );
+          pea.reset( new ProcessExitAction( false,
+                                            "",
+                                            am->getWorker(), wpu ) );
       }
 
       Datei fp;
@@ -364,7 +364,7 @@ StartProgOp::startprog( std::shared_ptr< WPUContext > wpu, ActionMessage *am )
         worker_unlink( tmpname );
         worker_unlink( tmpoutput );
 
-        if ( pea.getVal() != NULL ) {
+        if ( pea.get() != NULL ) {
             pea->callback( 0 );
         }
       }
@@ -403,7 +403,7 @@ StartProgOp::startprog( std::shared_ptr< WPUContext > wpu, ActionMessage *am )
 
       std::list< RefCount< ArgClass > > args;
 
-      args.push_back( new StringArg( dir ) );
+      args.push_back( RefCount< ArgClass >( new StringArg( dir ) ) );
       lm1->runCommand( "enter_dir", args );
     }
   }
