@@ -1,6 +1,6 @@
 /* startprogop.h
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2020 Ralf Hoffmann.
+ * Copyright (C) 2001-2021 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -41,16 +41,13 @@ public:
   StartProgOp( const StartProgOp &other );
   StartProgOp &operator=( const StartProgOp &other );
 
-  virtual StartProgOp *duplicate() const;
-  virtual bool isName(const char *);
-  virtual const char *getName();
-#if ! ( defined ( __GNUC__ ) && ( __GNUC__ < 3 ) )
-  using FunctionProto::run;
-#endif
-  int run( WPUContext *wpu, ActionMessage* );
-  virtual bool save(Datei*);
-  virtual const char *getDescription();
-  virtual int configure();
+  StartProgOp *duplicate() const override;
+  bool isName(const char *) override;
+  const char *getName() override;
+  int run( std::shared_ptr< WPUContext > wpu, ActionMessage* ) override;
+  bool save(Datei*) override;
+  const char *getDescription() override;
+  int configure() override;
   
   int doconfigure();
 
@@ -80,7 +77,7 @@ protected:
   // temp variables
   Lister *startlister,*endlister;
   
-  int startprog( WPUContext *wpu, ActionMessage *am );
+  int startprog( std::shared_ptr< WPUContext > wpu, ActionMessage *am );
 
   class SettingsWidgets
   {
