@@ -1,6 +1,6 @@
 /* stringmatcher_flexiblematch.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2012-2015 Ralf Hoffmann.
+ * Copyright (C) 2012-2022 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -22,6 +22,7 @@
 #include "stringmatcher_flexiblematch.hh"
 #include "aguix/lowlevelfunc.h"
 #include "aguix/utf8.hh"
+#include "aguix/util.h"
 #include <cctype>
 #include <algorithm>
 #include <functional>
@@ -164,23 +165,9 @@ bool StringMatcherFlexibleMatch::getMatchCaseSensitive() const
     return m_match_case_sensitive;
 }
 
-template <class T>
-struct my_tolower : public std::unary_function<T,T> 
-{
-    T operator() (const T& c) const 
-    {
-        return std::tolower( c );
-    }
-};
-
 void StringMatcherFlexibleMatch::createLoweredCase()
 {
-    m_match_string_lowercase = m_match_string;
-
-    std::transform( m_match_string_lowercase.begin(),
-                    m_match_string_lowercase.end(),
-                    m_match_string_lowercase.begin(),
-                    my_tolower<char>() );
+    m_match_string_lowercase = AGUIXUtils::tolower( m_match_string );
 }
 
 template <bool with_offsets> struct state_type {
