@@ -1,6 +1,6 @@
 /* tabprofilesop.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2017 Ralf Hoffmann.
+ * Copyright (C) 2017-2021 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -70,7 +70,7 @@ TabProfilesOp::getName()
 }
 
 int
-TabProfilesOp::run( WPUContext *wpu, ActionMessage *msg )
+TabProfilesOp::run( std::shared_ptr< WPUContext > wpu, ActionMessage *msg )
 {
     m_left_l = msg->getWorker()->getLister( 0 );
     m_right_l = msg->getWorker()->getLister( 1 );
