@@ -1,6 +1,6 @@
 /* virtualdirmode_config.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2019 Ralf Hoffmann.
+ * Copyright (C) 2019-2021 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -33,6 +33,10 @@
 #include "worker.h"
 #include "wconfig.h"
 #include "bookmarkdbproxy.hh"
+#include "flagreplacer.hh"
+#include "filereq.h"
+
+#define WORKER_DEFAULT_CUSTOM_LVB_FORMAT "{indicators} {modeinfo} - {freespace}"
 
 static void updateSortTabTitle( Kartei *k,
                                 CycleButton *sort_cyb,
@@ -127,12 +131,46 @@ static void updateFilterTabTitle( Kartei *k,
     k->updateOption( 1, new_text );
 }
 
+static void insertCustomLVBLineFlag( StringGadget *sg )
+{
+    if ( ! sg ) return;
+
+    FlagReplacer::FlagHelp flags;
+
+    flags.registerFlag( "{indicators}", catalog.getLocale( 1376 ) );
+    flags.registerFlag( "{modeinfo}", catalog.getLocale( 1377 ) );
+    flags.registerFlag( "{freespace}", catalog.getLocale( 1378 ) );
+    flags.registerFlag( "{cdi}", catalog.getLocale( 1379 ) );
+
+    std::string str1 = FlagReplacer::requestFlag( flags );
+
+    if ( str1.length() > 0 ) {
+        sg->insertAtCursor( str1.c_str() );
+    }
+}
+
+static void insertCustomDirectoryInfoCommandFlag( StringGadget *sg )
+{
+    if ( ! sg ) return;
+
+    FlagReplacer::FlagHelp flags;
+
+    flags.registerFlag( "{p}", catalog.getLocaleFlag( 1 ) );
+    flags.registerFlag( "{scripts}", catalog.getLocaleFlag( 53 ) );
+
+    std::string str1 = FlagReplacer::requestFlag( flags );
+
+    if ( str1.length() > 0 ) {
+        sg->insertAtCursor( str1.c_str() );
+    }
+}
+
 int VirtualDirMode::configure()
 {
     int endmode = -1;
     auto title = AGUIXUtils::formatStringToString( catalog.getLocale( 293 ),
                                                    getLocaleName() );
-    auto win = new AWindow( aguix, 10, 10, 10, 10, title.c_str(), AWindow::AWINDOW_DIALOG );
+    auto win = new AWindow( aguix, 10, 10, 10, 10, title.c_str(), AWindow::AWINDOW_NORMAL );
     win->create();
 
     AContainer *ac1 = win->setContainer( new AContainer( win, 1, 2 ), true );
@@ -377,7 +415,7 @@ int VirtualDirMode::configure()
     k1->add( subwin3 );
     subwin3->create();
 
-    AContainer *sw3_ac = subwin3->setContainer( new AContainer( subwin3, 1, 5 ), true );
+    AContainer *sw3_ac = subwin3->setContainer( new AContainer( subwin3, 1, 6 ), true );
     sw3_ac->setMinSpace( 5 );
     sw3_ac->setMaxSpace( 5 );
 
@@ -428,6 +466,34 @@ int VirtualDirMode::configure()
     Button *m_flag_b = ac3_2_1->addWidget( new Button( aguix, 0, 0, catalog.getLocale( 897 ), 0 ),
                                            2, 0, AContainer::CO_FIX );
 
+    AContainerBB *ac3_3 = static_cast<AContainerBB*>( sw3_ac->add( new AContainerBB( subwin3, 1, 3 ), 0, 5 ) );
+    ac3_3->setMinSpace( 5 );
+    ac3_3->setMaxSpace( 5 );
+
+    ChooseButton *enable_custom_lvb_line_cb = ac3_3->addWidget( new ChooseButton( aguix, 0, 0,
+                                                                                  m_enable_custom_lvb_line,
+                                                                                  catalog.getLocale( 1380 ), LABEL_RIGHT, 0 ), 0, 0, AContainer::CO_INCWNR );
+
+    AContainer *ac3_3_1 = ac3_3->add( new AContainer( subwin3, 4, 1 ), 0, 1 );
+    ac3_3_1->setMinSpace( 5 );
+    ac3_3_1->setMaxSpace( 5 );
+    ac3_3_1->add( new Text( aguix, 0, 0, catalog.getLocale( 1381 ) ), 0, 0, AContainer::CO_FIXNR | AContainer::ACONT_CENTER );
+    StringGadget *custom_lvb_format_sg = ac3_3_1->addWidget( new StringGadget( aguix, 0, 0, 100, m_custom_lvb_line.c_str(), 0 ), 1, 0, AContainer::CO_INCW );
+    Button *m_lvb_flag_b = ac3_3_1->addWidget( new Button( aguix, 0, 0, catalog.getLocale( 897 ), 0 ),
+                                               2, 0, AContainer::CO_FIX );
+    Button *m_lvb_default_b = ac3_3_1->addWidget( new Button( aguix, 0, 0, catalog.getLocale( 196 ), 0 ),
+                                                  3, 0, AContainer::CO_FIX );
+
+    AContainer *ac3_3_2 = ac3_3->add( new AContainer( subwin3, 4, 1 ), 0, 2 );
+    ac3_3_2->setMinSpace( 5 );
+    ac3_3_2->setMaxSpace( 5 );
+    ac3_3_2->add( new Text( aguix, 0, 0, catalog.getLocale( 1382 ) ), 0, 0, AContainer::CO_FIXNR | AContainer::ACONT_CENTER );
+    StringGadget *custom_directory_info_sg = ac3_3_2->addWidget( new StringGadget( aguix, 0, 0, 100, m_custom_directory_info_command.c_str(), 0 ), 1, 0, AContainer::CO_INCW );
+    Button *m_cdi_flag_b = ac3_3_2->addWidget( new Button( aguix, 0, 0, catalog.getLocale( 897 ), 0 ),
+                                               2, 0, AContainer::CO_FIX );
+    Button *m_cdi_file_b = ac3_3_2->addWidget( new Button( aguix, 0, 0, "F", 0 ),
+                                               3, 0, AContainer::CO_FIX );
+
     k1->setOption( subwin1, 0, catalog.getLocale( 1217 ) );
     k1->setOption( subwin2, 1, catalog.getLocale( 1218 ) );
     k1->setOption( subwin3, 2, catalog.getLocale( 1219 ) );
@@ -558,6 +624,38 @@ int VirtualDirMode::configure()
                     updateFilterTabTitle( k1, chb,
                                           tfilters,
                                           bookmark_filter_cycb );
+                } else if ( msg->button.button == m_lvb_flag_b ) {
+                    insertCustomLVBLineFlag( custom_lvb_format_sg );
+                } else if ( msg->button.button == m_lvb_default_b ) {
+                    custom_lvb_format_sg->setText( WORKER_DEFAULT_CUSTOM_LVB_FORMAT );
+                } else if ( msg->button.button == m_cdi_flag_b ) {
+                    insertCustomDirectoryInfoCommandFlag( custom_directory_info_sg );
+                } else if ( msg->button.button == m_cdi_file_b ) {
+                    FileRequester freq( aguix );
+                    std::string scriptdir = Worker::getDataDir();
+                    scriptdir += "/scripts";
+
+                    if ( freq.request_entry( catalog.getLocale( 265 ),
+                                             scriptdir.c_str(),
+                                             catalog.getLocale( 11 ),
+                                             catalog.getLocale( 8 ),
+                                             catalog.getLocale( 265 ),
+                                             false ) > 0 ) {
+                        std::string str1 = freq.getLastEntryStr();
+                        if ( ! str1.empty() ) {
+                            if ( AGUIXUtils::starts_with( str1, scriptdir ) ) {
+                                str1 = std::string( "{scripts}" ) + std::string( str1, scriptdir.size() );
+                            }
+                            
+                            std::string current_content = custom_directory_info_sg->getText();
+                            int pos = custom_directory_info_sg->getCursor();
+
+                            std::string newstr1( current_content, 0, pos );
+                            newstr1 += str1;
+                            newstr1 += std::string( current_content, pos );
+                            custom_directory_info_sg->setText( newstr1.c_str() );
+                        }
+                    }
                 }
                 break;
             case AG_CHOOSECLICKED:
@@ -721,6 +819,10 @@ int VirtualDirMode::configure()
         setEnableInfoLine( enable_info_line_cb->getState() );
         setInfoLineLUAMode( info_line_lua_mode_cb->getState() );
         setInfoLineContent( info_line_content_sg->getText() );
+
+        setEnableCustomLVBLine( enable_custom_lvb_line_cb->getState() );
+        setCustomLVBLine( custom_lvb_format_sg->getText() );
+        setCustomeDirectoryInfoCommand( custom_directory_info_sg->getText() );
     }
 
     delete win;
