@@ -1,6 +1,6 @@
 /* wconfig.h
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2020 Ralf Hoffmann.
+ * Copyright (C) 2001-2021 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -349,6 +349,9 @@ public:
     const std::map< std::string, struct directory_presets > &getDirectoryPresets() const;
 
     void setInitialCommand( const WConfigInitialCommand &cmd );
+
+    void setDisableBGCheckPrefix( const std::string &prefix );
+    const std::string getDisableBGCheckPrefix() const;
 protected:
   char *lang;
   unsigned int rows,columns;
@@ -506,6 +509,8 @@ protected:
     std::map< std::string, struct directory_presets > m_directory_presets;
 
     WConfigInitialCommand m_initial_command;
+
+    std::string m_disable_bg_check_prefix;
 };
 
 extern WConfig *wconfig;
