@@ -187,7 +187,7 @@ WConfigPanel::panel_action_t BookmarkColorPanel::setColors( List *colors )
     return PANEL_NOACTION;
 }
 
-void BookmarkColorPanel::run( Widget *elem, AGMessage &msg )
+void BookmarkColorPanel::run( Widget *elem, const AGMessage &msg )
 {
     int col;
 
