@@ -217,7 +217,7 @@ void ButtonPanel::showButtonBank()
   _baseconfig.getButtons()->closeEnum(id);
 }
 
-void ButtonPanel::run( Widget *elem, AGMessage &msg )
+void ButtonPanel::run( Widget *elem, const AGMessage &msg )
 {
   List *buttons = _baseconfig.getButtons();
 
