@@ -95,7 +95,7 @@ int ColorConfPanel::saveValues()
   return 0;
 }
 
-void ColorConfPanel::run( Widget *elem, AGMessage &msg )
+void ColorConfPanel::run( Widget *elem, const AGMessage &msg )
 {
   List *colors = tempconfig->getColors();
 
