@@ -214,7 +214,7 @@ int DirectoryPresetsPanel::saveValues()
     return 0;
 }
 
-void DirectoryPresetsPanel::run( Widget *elem, AGMessage &msg )
+void DirectoryPresetsPanel::run( Widget *elem, const AGMessage &msg )
 {
     if ( msg.type == AG_BUTTONCLICKED ) {
         if ( msg.button.button == m_addb ) {
