@@ -23,7 +23,7 @@
 #include "wconfig.h"
 #include "worker.h"
 #include "worker_locale.h"
-#include <aguix/choosebutton.h>
+#include "aguix/choosebutton.h"
 
 DirSizeConfPanel::DirSizeConfPanel( AWindow &basewin, WConfig &baseconfig ) : WConfigPanel( basewin, baseconfig )
 {
