@@ -114,7 +114,7 @@ int FontPanel::saveValues()
   return 0;
 }
 
-void FontPanel::run( Widget *elem, AGMessage &msg )
+void FontPanel::run( Widget *elem, const AGMessage &msg )
 {
   int erg, i;
   char *tstr;
