@@ -91,7 +91,7 @@ int HotkeyPanel::saveValues()
   return 0;
 }
 
-void HotkeyPanel::run( Widget *elem, AGMessage &msg )
+void HotkeyPanel::run( Widget *elem, const AGMessage &msg )
 {
   List *hotkeys = _baseconfig.getHotkeys();
   int trow;
