@@ -22,11 +22,11 @@
 #include "wconfig_lang.hh"
 #include "wconfig.h"
 #include "worker.h"
-#include <aguix/utf8.hh>
+#include "aguix/utf8.hh"
 #include "workerinitialsettings.hh"
 #include "nwc_path.hh"
 #include "worker_locale.h"
-#include <aguix/fieldlistview.h>
+#include "aguix/fieldlistview.h"
 
 LangPanel::LangPanel( AWindow &basewin, WConfig &baseconfig ) : WConfigPanel( basewin, baseconfig )
 {
