@@ -1,6 +1,6 @@
 /* worker.h
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2021 Ralf Hoffmann.
+ * Copyright (C) 2001-2022 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -70,6 +70,7 @@ class MenuTreeNode;
 class WConfig;
 class PersistentKVP;
 class PrefixDB;
+class FilterStash;
 
 class worker_version
 {
@@ -282,6 +283,8 @@ public:
 
     std::list< FileCommandLog::Entry > getCommandLog() const;
     void clearCommandLog();
+
+    std::shared_ptr< FilterStash > getFilterStash();
 protected:
   void createMainWin();
   void setupMainWin();
@@ -487,10 +490,15 @@ protected:
 
     void setCurrentWPU( std::shared_ptr< WPUContext > wpu );
 
+    void checkErrnoCount();
+    void tryIncreaseXZMemlimit();
+
     DeepPathStore m_path_store;
     std::unique_ptr< PersDeepPathStore > m_pers_path_store;
     std::unique_ptr< PersDeepPathStore > m_pers_path_store_archive;
 
+    std::shared_ptr< FilterStash > m_filter_stash;
+
     std::string m_current_hint;
     time_t m_hint_time;
     RefCount< HintDB > m_hint_db;
@@ -531,6 +539,9 @@ protected:
 
     static std::unique_ptr< FileCommandLog > m_command_log;
     static std::mutex m_command_log_mutex;
+
+    size_t m_last_enomem_count = 0;
+    size_t m_last_avfs_xz_memlimit_hit = 0;
 };
 
 #endif
