@@ -118,7 +118,7 @@ WPUContext::WPUContext( Worker *w, const command_list_t &coms, ActionMessage *ms
   extlist[1] = NULL;
   worker = w;
 
-  m_progress_callback = new WPUProgressCallback( worker );
+  m_progress_callback.reset( new WPUProgressCallback( worker ) );
   m_filesizes_calculated = false;
 
   curpos = 0;
@@ -1306,7 +1306,7 @@ std::string WPUContext::getTempName4File( const char *filename )
 
   calculateFilesizes();
 
-  TemporaryFileCache::TemporaryFileCacheEntry e = worker->getTempCopy( filename, m_progress_callback.getVal() );
+  TemporaryFileCache::TemporaryFileCacheEntry e = worker->getTempCopy( filename, m_progress_callback.get() );
 
   if ( ! e.isValid() ) return "";
 
@@ -1409,7 +1409,7 @@ void WPUContext::calculateFilesizes()
 
     m_filesizes_calculated = true;
 
-    if ( m_progress_callback.getVal() ) {
+    if ( m_progress_callback.get() ) {
         m_progress_callback->setCompleteFilesizes( sum );
     }
 }
