@@ -1,6 +1,6 @@
 /* wpucontext.h
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2002-2020 Ralf Hoffmann.
+ * Copyright (C) 2002-2021 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -68,14 +68,12 @@ public:
 
   void push( const std::string &elem );
   std::string pop();
-  std::string top();
-  bool isEmpty();
-  int size();
+  std::string top() const;
+  std::string stackEntry( int pos ) const;
+  bool isEmpty() const;
+  size_t size() const;
 protected:
-  int s, elems;
-  std::string *stack;
-  
-  void raise();
+  std::vector< std::string > stack;
 };
 
 class WPUContext
@@ -90,9 +88,10 @@ public:
   void push( int nr, std::string elem );
   std::string pop( int nr );
   std::string top( int nr );
+  std::string stackEntry( int nr, int pos );
   bool isEmpty( int nr );
   int size( int nr );
-  int next( ActionMessage *msg );
+  int next( std::shared_ptr< WPUContext > wpu, ActionMessage *msg );
   int openWin();
   int closeWin();
 
@@ -151,7 +150,7 @@ public:
   void setUseExtendedBasename( bool nv );
   bool getUseExtendedBasename() const;
   
-  typedef enum { WPU_LASTERROR_STACKEMPTY = 0 } wpu_lasterror_t;
+  typedef enum { WPU_LASTERROR_STACKEMPTY = 0, WPU_LASTERROR_INVALID_STACK } wpu_lasterror_t;
   const char *getBaseDir();
 
   struct ifp_symentry
@@ -165,9 +164,6 @@ public:
 
   std::string getTempName4File( const char *filename );
 
-  void ref();
-  int unref();
-
     const std::string &getPathDBFilename() const;
 private:
   WPUStack **stacks;
@@ -241,8 +237,6 @@ private:
   };
   std::list<class temp4filename_t*> tempnamelist;
 
-  int m_reference_count;
-
   std::list< TemporaryFileCache::TemporaryFileCacheEntry > m_temp_files;
   RefCount< WPUProgressCallback > m_progress_callback;
   bool m_filesizes_calculated;
